@@ -49,6 +49,7 @@ class Freebox(IPlugin):
 		for rs in self.configuration_plugin['param_Fb']:
 			log.msg("ids  :  %s" % (rs['ids']))
 			if rs['ids'] == idex :
+
 				if rs['idx_sec'] <> "":
 				# séparation de rs['idx'], nombre  
 					# search position '|' dans rs['idx']	
@@ -57,10 +58,8 @@ class Freebox(IPlugin):
 					log.msg("number  :  %s" % (int(rs['idx'])))
 		# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
 				for rx in range (1, int(rs['idx_sec'])): 				
-					resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx'])
-#					log.msg("resp  :  %s" % (req))				
-#					resp = requests.get (req)
-#					log.msg("resp  :  %s" % (resp))
+					resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
+					log.msg("resp  :  %s" % (resp))				
 		if bodies == "":
 			bodies = "j'ai rien compris aux switch"
 		return {"plugin": "Freebox",
